'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.Ability = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _noop = require('lodash/noop');

var _noop2 = _interopRequireDefault(_noop);

var _flattenDeep = require('lodash/flattenDeep');

var _flattenDeep2 = _interopRequireDefault(_flattenDeep);

var _Request = require('./Request');

var _verifyApplication = require('./middleware/verifyApplication');

var _handleEvent = require('./middleware/handleEvent');

var _handleRequest = require('./handleRequest');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var cLog = (0, _debug2.default)('alexa-ability:ability:constructor');
var uLog = (0, _debug2.default)('alexa-ability:ability:use');
var oLog = (0, _debug2.default)('alexa-ability:ability:on');

var warnAppId = function warnAppId() {
    return console.warn( // eslint-disable-line no-console
    'No "applicationId" provided, request may come from unauthorized sources');
};

var warnSent = function warnSent() {
    return console.warn( // eslint-disable-line no-console
    'Request already sent. Don\'t call "next" function after sending response.');
};

var Ability = exports.Ability = function () {
    function Ability() {
        var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

        _classCallCheck(this, Ability);

        // eslint-disable-line no-unused-vars
        this._stack = [];

        if (options.applicationId) {
            cLog('adding verifyApplication middleware');
            this.use((0, _verifyApplication.verifyApplication)(options.applicationId));
        } else {
            warnAppId();
        }
    }

    _createClass(Ability, [{
        key: 'use',
        value: function use() {
            var _stack;

            for (var _len = arguments.length, fns = Array(_len), _key = 0; _key < _len; _key++) {
                fns[_key] = arguments[_key];
            }

            (0, _assert2.default)(fns.length, 'expected at least one middleware');
            fns.forEach(function (fn) {
                (0, _assert2.default)(typeof fn === 'function', 'Expected function, got %o', fn);
                uLog('adding middleware function: ' + (fn.name || '<unnamed function>'));
            });

            (_stack = this._stack).push.apply(_stack, fns);
            return this;
        }
    }, {
        key: 'on',
        value: function on(event) {
            var _stack2;

            for (var _len2 = arguments.length, _handlers = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
                _handlers[_key2 - 1] = arguments[_key2];
            }

            var handlers = (0, _flattenDeep2.default)(_handlers);

            (0, _assert2.default)(typeof event === 'string', 'Expected string for event type');
            (0, _assert2.default)(handlers.length, 'Expected at least one handler');
            handlers.forEach(function (handler) {
                (0, _assert2.default)(typeof handler === 'function', 'Expected handler function, got %o', handler);
            });

            var fns = handlers.map(function (fn) {
                return (0, _handleEvent.handleEvent)(event, fn);
            });
            oLog('adding ' + fns.length + ' handlers for ' + event + ' event');
            (_stack2 = this._stack).push.apply(_stack2, _toConsumableArray(fns));
            return this;
        }
    }, {
        key: 'handle',
        value: function handle(event) {
            var callback = arguments.length <= 1 || arguments[1] === undefined ? _noop2.default : arguments[1];

            // build request object and attach listeners
            var req = new _Request.Request(event);
            req.on('finished', function () {
                return setImmediate(callback, null, req);
            });
            req.on('failed', function (err) {
                return setImmediate(callback, err, req);
            });

            // if we ever reach this function then everything has failed
            function done(err) {
                // halt execution early if response has been sent
                if (req.sent) {
                    warnSent();
                    return;
                }

                // just fail
                if (err) {
                    req.fail(err);
                    return;
                }

                req.fail(new Error('Unhandled event.'));
            }

            (0, _handleRequest.handleRequest)(req, this._stack, done);
            return req;
        }
    }]);

    return Ability;
}();