'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.handleRequest = handleRequest;

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _resolve = require('./resolve');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var log = (0, _debug2.default)('alexa-ability:ability:handle');
var warnSent = function warnSent() {
    return console.warn( // eslint-disable-line no-console
    'Request already sent. Don\'t call "next" function after sending response.');
};

function handleRequest(req, _stack, done) {
    var stack = [].concat(_toConsumableArray(_stack));
    var index = 0;

    function next(err) {
        if (req.sent) {
            // halt execution early if response has been sent
            warnSent();
            return;
        }

        // no more handlers? end
        if (index >= stack.length) {
            done(err);
            return;
        }

        // get next handling function
        var fn = stack[index++];
        var fnName = fn.name || fn.displayName || 'anonymous';

        // handle it correctly
        if (fn.length >= 3 && err) {
            // can handle error
            log('executing error handler: <' + fnName + '>');
            (0, _resolve.resolve)(fn, next, err, req);
        } else if (fn.length < 3 && !err) {
            // all's well! try the handler
            log('executing handler: <' + fnName + '>');
            (0, _resolve.resolve)(fn, next, req);
        } else {
            // not correct type of handler
            log('skipping handler: <' + fnName + '>');
            next(err);
        }
    }

    // start execution
    next();
}