'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.verifyApplication = verifyApplication;

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * A simple alexa-ability middleware to verify
 * that the requests applicationId matches the expected
 * applicationId.
 *
 * Included with alexa-ability because it's required to
 * get your skill past certified
 */

var log = (0, _debug2.default)('alexa-ability:verifyApplication');

function verifyApplication(id) {
    return function applicationVerifier(req, next) {
        var appId = (0, _get2.default)(req, 'raw.session.application.applicationId');

        log('checking requests applicationId: %s', appId);

        // verify that applicationId is the same
        if (appId !== id) {
            log('invalid applicationId: %s (expected %s)', appId, id);
            req.fail(new Error('Invalid applicationId'));
        } else {
            log('applicationId matches');
            next();
        }
    };
}